@@ -45,31 +45,6 @@
     BioC$Base <- Base
     options("BioC"=BioC)
 }
-# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-biocReposList <- function() {
-    msg <- c("  The biocReposList() function is deprecated.  ",
-             "Please use biocLite() to install\n  packages:\n",
-             "      source(\"http://bioconductor.org/biocLite.R\")\n",
-             "      biocLite(\"<pkgname>\")\n",
-             "  If you really need to get the list of Bioconductor package ",
-             "repositories (like\n  biocReposList() does), then do:\n",
-             "      source(\"http://bioconductor.org/biocLite.R\")\n",
-             "      biocinstallRepos()\n")
-    .Deprecated(msg=msg)
-    ## Locations of Bioconductor release repositories
-    VERSION <- "2.9"
-    bioc_topurl <- getOption("BioC")$Base$urls$bioc
-    if (is.null(bioc_topurl))
-        bioc_topurl <- "http://bioconductor.org"
-    pkg_topurl <- paste(bioc_topurl, "packages", VERSION, sep="/")
-    mkurl <- function(...) paste(pkg_topurl, ..., sep="/")
-    reposList <- c(bioc=mkurl("bioc"),
-                   aData=mkurl("data/annotation"),
-                   eData=mkurl("data/experiment"),
-                   extra=mkurl("extra"),
-                   cran="http://cran.fhcrc.org")
-    reposList
-}
 # ==========================================================================
 # RG:
 # multiput and multiget
@@ -130,9 +105,5 @@ copyEnv <- function(oldEnv, newEnv, all.names=FALSE) {
 
 ## Deprecated in v 2.11.2
 l2e <- function(vals, envir) {
-    .Deprecated(msg="'l2e' is deprecated, use 'list2env' instead ")
-    if (missing(envir))
-        list2env(vals, hash=TRUE)
-    else
-        list2env(vals, envir, hash=TRUE)
+    .Defunct("list2env", package="base")
 }
